@@ -2,7 +2,7 @@
 
 #
 # DaVinci Resolve 15.3.1 Debian package creator
-# Release 2019-04-07
+# Release 2019-05-21
 # By Daniel Tufvesson
 #
 
@@ -58,7 +58,7 @@ make_executable() {
 
 # Setup variables
 RESOLVE_VERSION=15.3.1
-DEB_STEPPING=1
+DEB_STEPPING=2
 case $1 in
     studio)
 	RESOLVE_NAME="DaVinci Resolve Studio"
@@ -131,6 +131,7 @@ copy_object ${UNPACK_DIR}/scripts/script.start ${RESOLVE_BASE_DIR}/scripts/
 copy_object ${UNPACK_DIR}/share/default-config-linux.dat ${RESOLVE_BASE_DIR}/configs/config.dat-pkg-default
 copy_object ${UNPACK_DIR}/share/log-conf.xml ${RESOLVE_BASE_DIR}/configs/log-conf.xml-pkg-default
 copy_object ${UNPACK_DIR}/share/default_cm_config.bin ${RESOLVE_BASE_DIR}/DolbyVision/config.bin-pkg-default
+copy_object ${UNPACK_DIR}/libs/libBlackmagicRawAPI.so ${RESOLVE_BASE_DIR}/bin/
 
 # Create udev rules
 create_directory ${DEB_DIR}/lib/udev/rules.d
@@ -153,10 +154,11 @@ Version=1.0
 Encoding=UTF-8
 Exec=/opt/resolve/bin/resolve
 Icon=/opt/resolve/graphics/DV_Resolve.png
-MimeType=
 Name=${RESOLVE_NAME}
 Terminal=false
+MimeType=application/x-resolveproj;
 Type=Application
+StartupNotify=true
 Categories=AudioVideo
 EOF
 
